@@ -113,6 +113,14 @@ sub Reroute
 }# end Reroute()
 
 
+sub Header
+{
+  my ($s, $name) = @_;
+  
+  $s->context->r->headers_in->{$name};
+}# end Header()
+
+
 sub DESTROY
 {
   my $s = shift;
@@ -177,6 +185,10 @@ Then you would get to it like this:
 
   my $upload = $Request->FileUpload('my_uploaded-file');
 
+=head2 Header( $name )
+
+Returns the value of an incoming http request header by the given name.
+
 =head1 BUGS
 
 It's possible that some bugs have found their way into this release.
